# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from common.run.v1alpha import run_pb2 as common_dot_run_dot_v1alpha_dot_run__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2
from vdp.pipeline.v1beta import component_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_component__definition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vdp/pipeline/v1beta/pipeline.proto\x12\x13vdp.pipeline.v1beta\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1c\x63ommon/run/v1alpha/run.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a vdp/pipeline/v1beta/common.proto\x1a.vdp/pipeline/v1beta/component_definition.proto\"\x95\x01\n\x0fLivenessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"v\n\x10LivenessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x96\x01\n\x10ReadinessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"w\n\x11ReadinessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x98\x02\n\tEndpoints\x12M\n\x08webhooks\x18\x01 \x03(\x0b\x32,.vdp.pipeline.v1beta.Endpoints.WebhooksEntryB\x03\xe0\x41\x03R\x08webhooks\x1aO\n\x0fWebhookEndpoint\x12\x15\n\x03url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03url\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x1ak\n\rWebhooksEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x44\n\x05value\x18\x02 \x01(\x0b\x32..vdp.pipeline.v1beta.Endpoints.WebhookEndpointR\x05value:\x02\x38\x01\"\xcc\r\n\x08Pipeline\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12*\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x34\n\x06recipe\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\x06recipe\x12@\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12@\n\x0b\x64\x65lete_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ndeleteTime\x12;\n\x07sharing\x18\x0f \x01(\x0b\x32\x1c.vdp.pipeline.v1beta.SharingB\x03\xe0\x41\x01R\x07sharing\x12\x38\n\x08metadata\x18\x10 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x08metadata\x12\"\n\nowner_name\x18\x11 \x01(\tB\x03\xe0\x41\x03R\townerName\x12\x45\n\x08releases\x18\x13 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x03\xe0\x41\x03R\x08releases\x12\x1b\n\x06readme\x18\x14 \x01(\tB\x03\xe0\x41\x01R\x06readme\x12\x44\n\npermission\x18\x15 \x01(\x0b\x32\x1f.vdp.pipeline.v1beta.PermissionB\x03\xe0\x41\x03R\npermission\x12M\n\nvisibility\x18\x16 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x03\xe0\x41\x03R\nvisibility\x12\x37\n\x05owner\x18\x17 \x01(\x0b\x32\x17.core.mgmt.v1beta.OwnerB\x03\xe0\x41\x03H\x01R\x05owner\x88\x01\x01\x12Z\n\x12\x64\x61ta_specification\x18\x18 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationB\x03\xe0\x41\x03R\x11\x64\x61taSpecification\x12\x17\n\x04tags\x18\x19 \x03(\tB\x03\xe0\x41\x01R\x04tags\x12>\n\x05stats\x18\x1a \x01(\x0b\x32#.vdp.pipeline.v1beta.Pipeline.StatsB\x03\xe0\x41\x03R\x05stats\x12\"\n\nraw_recipe\x18\x1b \x01(\tB\x03\xe0\x41\x01R\trawRecipe\x12\'\n\nsource_url\x18\x1c \x01(\tB\x03\xe0\x41\x01H\x02R\tsourceUrl\x88\x01\x01\x12\x35\n\x11\x64ocumentation_url\x18\x1d \x01(\tB\x03\xe0\x41\x01H\x03R\x10\x64ocumentationUrl\x88\x01\x01\x12\"\n\x07license\x18\x1e \x01(\tB\x03\xe0\x41\x01H\x04R\x07license\x88\x01\x01\x12-\n\rprofile_image\x18\x1f \x01(\tB\x03\xe0\x41\x01H\x05R\x0cprofileImage\x88\x01\x01\x12\x41\n\tendpoints\x18  \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.EndpointsB\x03\xe0\x41\x03R\tendpoints\x1a\xa6\x01\n\x05Stats\x12)\n\x0enumber_of_runs\x18\x01 \x01(\x05\x42\x03\xe0\x41\x03R\x0cnumberOfRuns\x12\x43\n\rlast_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x0blastRunTime\x12-\n\x10number_of_clones\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x0enumberOfClones\"L\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\x12\x0f\n\x0bVIEW_RECIPE\x10\x03\"W\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x16\n\x12VISIBILITY_PRIVATE\x10\x01\x12\x15\n\x11VISIBILITY_PUBLIC\x10\x02\x42\x0e\n\x0c_descriptionB\x08\n\x06_ownerB\r\n\x0b_source_urlB\x14\n\x12_documentation_urlB\n\n\x08_licenseB\x10\n\x0e_profile_imageJ\x04\x08\r\x10\x0eJ\x04\x08\x12\x10\x13\"\xb7\x01\n\x0fTriggerMetadata\x12M\n\x06traces\x18\x01 \x03(\x0b\x32\x30.vdp.pipeline.v1beta.TriggerMetadata.TracesEntryB\x03\xe0\x41\x03R\x06traces\x1aU\n\x0bTracesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.vdp.pipeline.v1beta.TraceR\x05value:\x02\x38\x01\"\x87\x03\n\x05Trace\x12\x42\n\x08statuses\x18\x01 \x03(\x0e\x32!.vdp.pipeline.v1beta.Trace.StatusB\x03\xe0\x41\x03R\x08statuses\x12\x34\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x06inputs\x12\x36\n\x07outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x07outputs\x12\x32\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x05\x65rror\x12:\n\x17\x63ompute_time_in_seconds\x18\x05 \x01(\x02\x42\x03\xe0\x41\x03R\x14\x63omputeTimeInSeconds\"\\\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10STATUS_COMPLETED\x10\x01\x12\x12\n\x0eSTATUS_SKIPPED\x10\x02\x12\x10\n\x0cSTATUS_ERROR\x10\x03\"\x14\n\x12GetHubStatsRequest\"\x9d\x01\n\x13GetHubStatsResponse\x12@\n\x1anumber_of_public_pipelines\x18\x01 \x01(\x05\x42\x03\xe0\x41\x03R\x17numberOfPublicPipelines\x12\x44\n\x1cnumber_of_featured_pipelines\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\x19numberOfFeaturedPipelines\"\xc4\x05\n\x0fPipelineRelease\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12*\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x34\n\x06recipe\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x06recipe\x12@\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12@\n\x0b\x64\x65lete_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ndeleteTime\x12\x19\n\x05\x61lias\x18\x0b \x01(\tB\x03\xe0\x41\x03R\x05\x61lias\x12\x33\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12\x1b\n\x06readme\x18\r \x01(\tB\x03\xe0\x41\x01R\x06readme\x12Z\n\x12\x64\x61ta_specification\x18\x0e \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationB\x03\xe0\x41\x03R\x11\x64\x61taSpecification\x12\"\n\nraw_recipe\x18\x0f \x01(\tB\x03\xe0\x41\x01R\trawRecipe\x12\x41\n\tendpoints\x18\x10 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.EndpointsB\x03\xe0\x41\x03R\tendpointsB\x0e\n\x0c_descriptionJ\x04\x08\t\x10\n\"\xce\x03\n\x14ListPipelinesRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x12R\n\nvisibility\x18\x06 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x07 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deletedB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\xaa\x01\n\x15ListPipelinesResponse\x12@\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x03R\tpipelines\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xff\x03\n\x1dListNamespacePipelinesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12%\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x04 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x12R\n\nvisibility\x18\x07 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x08 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deletedB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\xb3\x01\n\x1eListNamespacePipelinesResponse\x12@\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x03R\tpipelines\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\x85\x01\n\x15LookUpPipelineRequest\x12!\n\tpermalink\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tpermalink\x12@\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"X\n\x16LookUpPipelineResponse\x12>\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x03R\x08pipeline\"\x83\x01\n\x1e\x43reateNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x39\n\x08pipeline\x18\x02 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"a\n\x1f\x43reateNamespacePipelineResponse\x12>\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x03R\x08pipeline\"\xb6\x01\n\x1bGetNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"^\n\x1cGetNamespacePipelineResponse\x12>\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x03R\x08pipeline\"\xeb\x01\n\x1eUpdateNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\x39\n\x08pipeline\x18\x03 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"a\n\x1fUpdateNamespacePipelineResponse\x12>\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x03R\x08pipeline\"n\n\x1e\x44\x65leteNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\"!\n\x1f\x44\x65leteNamespacePipelineResponse\"p\n ValidateNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\"\x8b\x01\n!ValidateNamespacePipelineResponse\x12\x1d\n\x07success\x18\x01 \x01(\x08\x42\x03\xe0\x41\x03R\x07success\x12G\n\x06\x65rrors\x18\x02 \x03(\x0b\x32*.vdp.pipeline.v1beta.ErrPipelineValidationB\x03\xe0\x41\x03R\x06\x65rrors\"\x9b\x01\n\x1eRenameNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12+\n\x0fnew_pipeline_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\rnewPipelineId\"a\n\x1fRenameNamespacePipelineResponse\x12>\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x03R\x08pipeline\"\xbf\x02\n\x1d\x43loneNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12;\n\x07sharing\x18\x05 \x01(\x0b\x32\x1c.vdp.pipeline.v1beta.SharingB\x03\xe0\x41\x01R\x07sharing\x12\x33\n\x13target_namespace_id\x18\x06 \x01(\tB\x03\xe0\x41\x02R\x11targetNamespaceId\x12\x31\n\x12target_pipeline_id\x18\x07 \x01(\tB\x03\xe0\x41\x02R\x10targetPipelineIdJ\x04\x08\x03\x10\x04\" \n\x1e\x43loneNamespacePipelineResponse\"\xea\x02\n$CloneNamespacePipelineReleaseRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\"\n\nrelease_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\treleaseId\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12;\n\x07sharing\x18\x06 \x01(\x0b\x32\x1c.vdp.pipeline.v1beta.SharingB\x03\xe0\x41\x01R\x07sharing\x12\x33\n\x13target_namespace_id\x18\x07 \x01(\tB\x03\xe0\x41\x02R\x11targetNamespaceId\x12\x31\n\x12target_pipeline_id\x18\x08 \x01(\tB\x03\xe0\x41\x02R\x10targetPipelineIdJ\x04\x08\x04\x10\x05\"\'\n%CloneNamespacePipelineReleaseResponse\"\xc8\x01\n!SendNamespacePipelineEventRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\x14\n\x05\x65vent\x18\x03 \x01(\tR\x05\x65vent\x12\x12\n\x04\x63ode\x18\x04 \x01(\tR\x04\x63ode\x12+\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\"Q\n\"SendNamespacePipelineEventResponse\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\"\xf3\x01\n(SendNamespacePipelineReleaseEventRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\"\n\nrelease_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\treleaseId\x12\x14\n\x05\x65vent\x18\x04 \x01(\tR\x05\x65vent\x12\x12\n\x04\x63ode\x18\x05 \x01(\tR\x04\x63ode\x12+\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\"X\n)SendNamespacePipelineReleaseEventResponse\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\"\xe0\x01\n\x1fTriggerNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\x34\n\x06inputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\x06inputs\x12\x39\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataB\x03\xe0\x41\x02R\x04\x64\x61ta\"\xa1\x01\n TriggerNamespacePipelineResponse\x12\x36\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x07outputs\x12\x45\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataB\x03\xe0\x41\x03R\x08metadata\"\xea\x01\n)TriggerNamespacePipelineWithStreamRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\x34\n\x06inputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x06inputs\x12\x39\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataB\x03\xe0\x41\x01R\x04\x64\x61ta\"\xab\x01\n*TriggerNamespacePipelineWithStreamResponse\x12\x36\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x07outputs\x12\x45\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataB\x03\xe0\x41\x03R\x08metadata\"\xe5\x01\n$TriggerAsyncNamespacePipelineRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\x34\n\x06inputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x06inputs\x12\x39\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataB\x03\xe0\x41\x01R\x04\x64\x61ta\"i\n%TriggerAsyncNamespacePipelineResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xb5\x01\n%CreateNamespacePipelineReleaseRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12>\n\x07release\x18\x03 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"m\n&CreateNamespacePipelineReleaseResponse\x12\x43\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x03\xe0\x41\x03R\x07release\"\x97\x03\n$ListNamespacePipelineReleasesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12%\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x05 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x06 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x07 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xbf\x01\n%ListNamespacePipelineReleasesResponse\x12\x45\n\x08releases\x18\x01 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x03\xe0\x41\x03R\x08releases\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xe1\x01\n\"GetNamespacePipelineReleaseRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\"\n\nrelease_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\treleaseId\x12@\n\x04view\x18\x04 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"j\n#GetNamespacePipelineReleaseResponse\x12\x43\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x03\xe0\x41\x03R\x07release\"\x9b\x02\n%UpdateNamespacePipelineReleaseRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\"\n\nrelease_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\treleaseId\x12>\n\x07release\x18\x04 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\x12@\n\x0bupdate_mask\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"m\n&UpdateNamespacePipelineReleaseResponse\x12\x43\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x03\xe0\x41\x03R\x07release\"\x99\x01\n%DeleteNamespacePipelineReleaseRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\"\n\nrelease_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\treleaseId\"(\n&DeleteNamespacePipelineReleaseResponse\"\x8b\x02\n&TriggerNamespacePipelineReleaseRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\"\n\nrelease_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\treleaseId\x12\x34\n\x06inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x06inputs\x12\x39\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataB\x03\xe0\x41\x01R\x04\x64\x61ta\"\xa8\x01\n\'TriggerNamespacePipelineReleaseResponse\x12\x36\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x07outputs\x12\x45\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataB\x03\xe0\x41\x03R\x08metadata\"\x90\x02\n+TriggerAsyncNamespacePipelineReleaseRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\"\n\nrelease_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\treleaseId\x12\x34\n\x06inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x06inputs\x12\x39\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataB\x03\xe0\x41\x01R\x04\x64\x61ta\"p\n,TriggerAsyncNamespacePipelineReleaseResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xa3\x01\n\x19\x43reateUserPipelineRequest\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\x12K\n\x06parent\x18\x02 \x01(\tB3\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\"W\n\x1a\x43reateUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x9f\x04\n\x18ListUserPipelinesRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12K\n\x06parent\x18\x05 \x01(\tB3\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\x12+\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x12R\n\nvisibility\x18\x07 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x08 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deletedB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\x9f\x01\n\x19ListUserPipelinesResponse\x12;\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\tpipelines\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xb5\x01\n\x16GetUserPipelineRequest\x12P\n\x04name\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12@\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"T\n\x17GetUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x9d\x01\n\x19UpdateUserPipelineRequest\x12>\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x02R\x08pipeline\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"W\n\x1aUpdateUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"m\n\x19\x44\x65leteUserPipelineRequest\x12P\n\x04name\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"\x1c\n\x1a\x44\x65leteUserPipelineResponse\"I\n\x15\x45rrPipelineValidation\x12\x1a\n\x08location\x18\x01 \x01(\tR\x08location\x12\x14\n\x05\x65rror\x18\x02 \x01(\tR\x05\x65rror\"o\n\x1bValidateUserPipelineRequest\x12P\n\x04name\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"|\n\x1cValidateUserPipelineResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x42\n\x06\x65rrors\x18\x02 \x03(\x0b\x32*.vdp.pipeline.v1beta.ErrPipelineValidationR\x06\x65rrors\"\x9a\x01\n\x19RenameUserPipelineRequest\x12P\n\x04name\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12+\n\x0fnew_pipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\rnewPipelineId\"W\n\x1aRenameUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xd5\x01\n\x1aTriggerUserPipelineRequest\x12P\n\x04name\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"\x92\x01\n\x1bTriggerUserPipelineResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xdf\x01\n$TriggerUserPipelineWithStreamRequest\x12P\n\x04name\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"\x9c\x01\n%TriggerUserPipelineWithStreamResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xcd\x01\n\x0bTriggerData\x12\x38\n\x08variable\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x08variable\x12I\n\x06secret\x18\x02 \x03(\x0b\x32,.vdp.pipeline.v1beta.TriggerData.SecretEntryB\x03\xe0\x41\x01R\x06secret\x1a\x39\n\x0bSecretEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xda\x01\n\x1fTriggerAsyncUserPipelineRequest\x12P\n\x04name\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"d\n TriggerAsyncUserPipelineResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xb6\x01\n CreateUserPipelineReleaseRequest\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\x12R\n\x06parent\x18\x02 \x01(\tB:\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\"c\n!CreateUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x98\x03\n\x1fListUserPipelineReleasesRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12R\n\x06parent\x18\x05 \x01(\tB:\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\x12+\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xab\x01\n ListUserPipelineReleasesResponse\x12@\n\x08releases\x18\x01 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x08releases\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xcb\x01\n\x1dGetUserPipelineReleaseRequest\x12_\n\x04name\x18\x01 \x01(\tBK\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12@\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"`\n\x1eGetUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xa9\x01\n UpdateUserPipelineReleaseRequest\x12\x43\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x03\xe0\x41\x02R\x07release\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"c\n!UpdateUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x83\x01\n DeleteUserPipelineReleaseRequest\x12_\n\x04name\x18\x01 \x01(\tBK\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"#\n!DeleteUserPipelineReleaseResponse\"\x84\x01\n!RestoreUserPipelineReleaseRequest\x12_\n\x04name\x18\x01 \x01(\tBK\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"d\n\"RestoreUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xbf\x01\n RenameUserPipelineReleaseRequest\x12_\n\x04name\x18\x01 \x01(\tBK\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12:\n\x17new_pipeline_release_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x14newPipelineReleaseId\"c\n!RenameUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xeb\x01\n!TriggerUserPipelineReleaseRequest\x12_\n\x04name\x18\x01 \x01(\tBK\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"\x99\x01\n\"TriggerUserPipelineReleaseResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xf0\x01\n&TriggerAsyncUserPipelineReleaseRequest\x12_\n\x04name\x18\x01 \x01(\tBK\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"k\n\'TriggerAsyncUserPipelineReleaseResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xb3\x01\n!CreateOrganizationPipelineRequest\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\x12S\n\x06parent\x18\x02 \x01(\tB;\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\"_\n\"CreateOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xaf\x04\n ListOrganizationPipelinesRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12S\n\x06parent\x18\x05 \x01(\tB;\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\x12+\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x12R\n\nvisibility\x18\x07 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x08 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deletedB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\xa7\x01\n!ListOrganizationPipelinesResponse\x12;\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\tpipelines\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc5\x01\n\x1eGetOrganizationPipelineRequest\x12X\n\x04name\x18\x01 \x01(\tBD\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12@\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"\\\n\x1fGetOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xa5\x01\n!UpdateOrganizationPipelineRequest\x12>\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x03\xe0\x41\x02R\x08pipeline\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"_\n\"UpdateOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"}\n!DeleteOrganizationPipelineRequest\x12X\n\x04name\x18\x01 \x01(\tBD\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"$\n\"DeleteOrganizationPipelineResponse\"\x7f\n#ValidateOrganizationPipelineRequest\x12X\n\x04name\x18\x01 \x01(\tBD\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"\x84\x01\n$ValidateOrganizationPipelineResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x42\n\x06\x65rrors\x18\x02 \x03(\x0b\x32*.vdp.pipeline.v1beta.ErrPipelineValidationR\x06\x65rrors\"\xaa\x01\n!RenameOrganizationPipelineRequest\x12X\n\x04name\x18\x01 \x01(\tBD\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12+\n\x0fnew_pipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\rnewPipelineId\"_\n\"RenameOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xe5\x01\n\"TriggerOrganizationPipelineRequest\x12X\n\x04name\x18\x01 \x01(\tBD\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"\x9a\x01\n#TriggerOrganizationPipelineResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xeb\x01\n(TriggerOrganizationPipelineStreamRequest\x12X\n\x04name\x18\x01 \x01(\tBD\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"\xa0\x01\n)TriggerOrganizationPipelineStreamResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xea\x01\n\'TriggerAsyncOrganizationPipelineRequest\x12X\n\x04name\x18\x01 \x01(\tBD\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"l\n(TriggerAsyncOrganizationPipelineResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xc6\x01\n(CreateOrganizationPipelineReleaseRequest\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\x12Z\n\x06parent\x18\x02 \x01(\tBB\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\"k\n)CreateOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xa8\x03\n\'ListOrganizationPipelineReleasesRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12Z\n\x06parent\x18\x05 \x01(\tBB\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\x12+\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xb3\x01\n(ListOrganizationPipelineReleasesResponse\x12@\n\x08releases\x18\x01 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x08releases\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xdb\x01\n%GetOrganizationPipelineReleaseRequest\x12g\n\x04name\x18\x01 \x01(\tBS\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12@\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"h\n&GetOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xb1\x01\n(UpdateOrganizationPipelineReleaseRequest\x12\x43\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x03\xe0\x41\x02R\x07release\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"k\n)UpdateOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x93\x01\n(DeleteOrganizationPipelineReleaseRequest\x12g\n\x04name\x18\x01 \x01(\tBS\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"+\n)DeleteOrganizationPipelineReleaseResponse\"\x94\x01\n)RestoreOrganizationPipelineReleaseRequest\x12g\n\x04name\x18\x01 \x01(\tBS\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"l\n*RestoreOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xcf\x01\n(RenameOrganizationPipelineReleaseRequest\x12g\n\x04name\x18\x01 \x01(\tBS\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12:\n\x17new_pipeline_release_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x14newPipelineReleaseId\"k\n)RenameOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xfb\x01\n)TriggerOrganizationPipelineReleaseRequest\x12g\n\x04name\x18\x01 \x01(\tBS\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"\xa1\x01\n*TriggerOrganizationPipelineReleaseResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\x80\x02\n.TriggerAsyncOrganizationPipelineReleaseRequest\x12g\n\x04name\x18\x01 \x01(\tBS\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe0\x41\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x34\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .vdp.pipeline.v1beta.TriggerDataR\x04\x64\x61ta\"s\n/TriggerAsyncOrganizationPipelineReleaseResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"=\n\x13GetOperationRequest\x12&\n\x0coperation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0boperationId\"X\n\x14GetOperationResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xbe\x02\n\x19ListPipelinesAdminRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xa0\x01\n\x1aListPipelinesAdminResponse\x12;\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\tpipelines\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc5\x02\n ListPipelineReleasesAdminRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12@\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xac\x01\n!ListPipelineReleasesAdminResponse\x12@\n\x08releases\x18\x01 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x08releases\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc3\x01\n\x1aLookUpPipelineAdminRequest\x12Z\n\tpermalink\x18\x01 \x01(\tB<\x92\x41\x18\xca>\x15\xfa\x02\x12pipeline_permalink\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\tpermalink\x12@\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"X\n\x1bLookUpPipelineAdminResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x87\x02\n\x17ListPipelineRunsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bpipeline_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\npipelineId\x12\x17\n\x04page\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01R\x04page\x12 \n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01R\x08pageSize\x12 \n\x06\x66ilter\x18\x06 \x01(\tB\x03\xe0\x41\x01H\x00R\x06\x66ilter\x88\x01\x01\x12#\n\x08order_by\x18\x07 \x01(\tB\x03\xe0\x41\x01H\x01R\x07orderBy\x88\x01\x01\x42\t\n\x07_filterB\x0b\n\t_order_byJ\x04\x08\x05\x10\x06\"\xbf\x02\n$ListPipelineRunsByCreditOwnerRequest\x12\x17\n\x04page\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01R\x04page\x12 \n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x08pageSize\x12 \n\x06\x66ilter\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x00R\x06\x66ilter\x88\x01\x01\x12#\n\x08order_by\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x01R\x07orderBy\x88\x01\x01\x12\x35\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\x05start\x88\x01\x01\x12\x33\n\x04stop\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03R\x04stop\x88\x01\x01\x42\t\n\x07_filterB\x0b\n\t_order_byB\x08\n\x06_startB\x07\n\x05_stop\"\xc5\x01\n\x18ListPipelineRunsResponse\x12J\n\rpipeline_runs\x18\x01 \x03(\x0b\x32 .vdp.pipeline.v1beta.PipelineRunB\x03\xe0\x41\x03R\x0cpipelineRuns\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12\x17\n\x04page\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x04page\x12 \n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\"\xd2\x01\n%ListPipelineRunsByCreditOwnerResponse\x12J\n\rpipeline_runs\x18\x01 \x03(\x0b\x32 .vdp.pipeline.v1beta.PipelineRunB\x03\xe0\x41\x03R\x0cpipelineRuns\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12\x17\n\x04page\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x04page\x12 \n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\"\xcd\x02\n\x18ListComponentRunsRequest\x12+\n\x0fpipeline_run_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\rpipelineRunId\x12\x1c\n\x04page\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x04page\x88\x01\x01\x12%\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01H\x01R\x08pageSize\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x12#\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x03R\x07orderBy\x88\x01\x01\x12@\n\x04view\x18\x06 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x03\xe0\x41\x01H\x04R\x04view\x88\x01\x01\x42\x07\n\x05_pageB\x0c\n\n_page_sizeB\t\n\x07_filterB\x0b\n\t_order_byB\x07\n\x05_view\"\xc9\x01\n\x19ListComponentRunsResponse\x12M\n\x0e\x63omponent_runs\x18\x01 \x03(\x0b\x32!.vdp.pipeline.v1beta.ComponentRunB\x03\xe0\x41\x03R\rcomponentRuns\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12\x17\n\x04page\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x04page\x12 \n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\"q\n\rFileReference\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\x17\n\x04type\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04type\x12\x17\n\x04size\x18\x03 \x01(\x03\x42\x03\xe0\x41\x02R\x04size\x12\x15\n\x03url\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x03url\"\xfd\x07\n\x0bPipelineRun\x12&\n\x0cpipeline_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0bpipelineUid\x12-\n\x10pipeline_run_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0epipelineRunUid\x12.\n\x10pipeline_version\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0fpipelineVersion\x12:\n\x06status\x18\x04 \x01(\x0e\x32\x1d.common.run.v1alpha.RunStatusB\x03\xe0\x41\x03R\x06status\x12:\n\x06source\x18\x05 \x01(\x0e\x32\x1d.common.run.v1alpha.RunSourceB\x03\xe0\x41\x03R\x06source\x12\x32\n\x0etotal_duration\x18\x06 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x01H\x00R\rtotalDuration\x88\x01\x01\x12(\n\trunner_id\x18\x07 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x01H\x01R\x08runnerId\x88\x01\x01\x12\x37\n\x06inputs\x18\n \x03(\x0b\x32\x17.google.protobuf.StructB\x06\xe0\x41\x03\xe0\x41\x01R\x06inputs\x12\x39\n\x07outputs\x18\x0c \x03(\x0b\x32\x17.google.protobuf.StructB\x06\xe0\x41\x03\xe0\x41\x01R\x07outputs\x12\x45\n\x0frecipe_snapshot\x18\r \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0erecipeSnapshot\x12>\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstartTime\x12L\n\rcomplete_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x01H\x02R\x0c\x63ompleteTime\x88\x01\x01\x12!\n\x05\x65rror\x18\x10 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x01H\x03R\x05\x65rror\x88\x01\x01\x12\x30\n\rcredit_amount\x18\x11 \x01(\x02\x42\x06\xe0\x41\x03\xe0\x41\x01H\x04R\x0c\x63reditAmount\x88\x01\x01\x12Z\n\x12\x64\x61ta_specification\x18\x12 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationB\x03\xe0\x41\x03R\x11\x64\x61taSpecification\x12,\n\x0bpipeline_id\x18\x13 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x01H\x05R\npipelineId\x88\x01\x01\x42\x11\n\x0f_total_durationB\x0c\n\n_runner_idB\x10\n\x0e_complete_timeB\x08\n\x06_errorB\x10\n\x0e_credit_amountB\x0e\n\x0c_pipeline_idJ\x04\x08\t\x10\nJ\x04\x08\x0b\x10\x0c\"\x97\x06\n\x0c\x43omponentRun\x12-\n\x10pipeline_run_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0epipelineRunUid\x12&\n\x0c\x63omponent_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0b\x63omponentId\x12:\n\x06status\x18\x03 \x01(\x0e\x32\x1d.common.run.v1alpha.RunStatusB\x03\xe0\x41\x03R\x06status\x12\x32\n\x0etotal_duration\x18\x04 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x01H\x00R\rtotalDuration\x88\x01\x01\x12>\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstartTime\x12L\n\rcomplete_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x01H\x01R\x0c\x63ompleteTime\x88\x01\x01\x12!\n\x05\x65rror\x18\x07 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x01H\x02R\x05\x65rror\x88\x01\x01\x12R\n\x10inputs_reference\x18\x08 \x03(\x0b\x32\".vdp.pipeline.v1beta.FileReferenceB\x03\xe0\x41\x03R\x0finputsReference\x12\x37\n\x06inputs\x18\t \x03(\x0b\x32\x17.google.protobuf.StructB\x06\xe0\x41\x03\xe0\x41\x01R\x06inputs\x12T\n\x11outputs_reference\x18\n \x03(\x0b\x32\".vdp.pipeline.v1beta.FileReferenceB\x03\xe0\x41\x03R\x10outputsReference\x12\x39\n\x07outputs\x18\x0b \x03(\x0b\x32\x17.google.protobuf.StructB\x06\xe0\x41\x03\xe0\x41\x01R\x07outputs\x12\x30\n\rcredit_amount\x18\x0c \x01(\x02\x42\x06\xe0\x41\x03\xe0\x41\x01H\x03R\x0c\x63reditAmount\x88\x01\x01\x42\x11\n\x0f_total_durationB\x10\n\x0e_complete_timeB\x08\n\x06_errorB\x10\n\x0e_credit_amount*U\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_INACTIVE\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x0f\n\x0bSTATE_ERROR\x10\x03\x42\xdc\x01\n\x17\x63om.vdp.pipeline.v1betaB\rPipelineProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\rPipelineProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _ENDPOINTS_WEBHOOKENDPOINT.fields_by_name['url']._options = None
  _ENDPOINTS_WEBHOOKENDPOINT.fields_by_name['url']._serialized_options = b'\340A\003'
  _ENDPOINTS_WEBHOOKENDPOINT.fields_by_name['description']._options = None
  _ENDPOINTS_WEBHOOKENDPOINT.fields_by_name['description']._serialized_options = b'\340A\003'
  _ENDPOINTS_WEBHOOKSENTRY._options = None
  _ENDPOINTS_WEBHOOKSENTRY._serialized_options = b'8\001'
  _ENDPOINTS.fields_by_name['webhooks']._options = None
  _ENDPOINTS.fields_by_name['webhooks']._serialized_options = b'\340A\003'
  _PIPELINE_STATS.fields_by_name['number_of_runs']._options = None
  _PIPELINE_STATS.fields_by_name['number_of_runs']._serialized_options = b'\340A\003'
  _PIPELINE_STATS.fields_by_name['last_run_time']._options = None
  _PIPELINE_STATS.fields_by_name['last_run_time']._serialized_options = b'\340A\003'
  _PIPELINE_STATS.fields_by_name['number_of_clones']._options = None
  _PIPELINE_STATS.fields_by_name['number_of_clones']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['name']._options = None
  _PIPELINE.fields_by_name['name']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['uid']._options = None
  _PIPELINE.fields_by_name['uid']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['id']._options = None
  _PIPELINE.fields_by_name['id']._serialized_options = b'\340A\005'
  _PIPELINE.fields_by_name['description']._options = None
  _PIPELINE.fields_by_name['description']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['recipe']._options = None
  _PIPELINE.fields_by_name['recipe']._serialized_options = b'\340A\002'
  _PIPELINE.fields_by_name['create_time']._options = None
  _PIPELINE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['update_time']._options = None
  _PIPELINE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['delete_time']._options = None
  _PIPELINE.fields_by_name['delete_time']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['sharing']._options = None
  _PIPELINE.fields_by_name['sharing']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['metadata']._options = None
  _PIPELINE.fields_by_name['metadata']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['owner_name']._options = None
  _PIPELINE.fields_by_name['owner_name']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['releases']._options = None
  _PIPELINE.fields_by_name['releases']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['readme']._options = None
  _PIPELINE.fields_by_name['readme']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['permission']._options = None
  _PIPELINE.fields_by_name['permission']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['visibility']._options = None
  _PIPELINE.fields_by_name['visibility']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['owner']._options = None
  _PIPELINE.fields_by_name['owner']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['data_specification']._options = None
  _PIPELINE.fields_by_name['data_specification']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['tags']._options = None
  _PIPELINE.fields_by_name['tags']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['stats']._options = None
  _PIPELINE.fields_by_name['stats']._serialized_options = b'\340A\003'
  _PIPELINE.fields_by_name['raw_recipe']._options = None
  _PIPELINE.fields_by_name['raw_recipe']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['source_url']._options = None
  _PIPELINE.fields_by_name['source_url']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['documentation_url']._options = None
  _PIPELINE.fields_by_name['documentation_url']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['license']._options = None
  _PIPELINE.fields_by_name['license']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['profile_image']._options = None
  _PIPELINE.fields_by_name['profile_image']._serialized_options = b'\340A\001'
  _PIPELINE.fields_by_name['endpoints']._options = None
  _PIPELINE.fields_by_name['endpoints']._serialized_options = b'\340A\003'
  _TRIGGERMETADATA_TRACESENTRY._options = None
  _TRIGGERMETADATA_TRACESENTRY._serialized_options = b'8\001'
  _TRIGGERMETADATA.fields_by_name['traces']._options = None
  _TRIGGERMETADATA.fields_by_name['traces']._serialized_options = b'\340A\003'
  _TRACE.fields_by_name['statuses']._options = None
  _TRACE.fields_by_name['statuses']._serialized_options = b'\340A\003'
  _TRACE.fields_by_name['inputs']._options = None
  _TRACE.fields_by_name['inputs']._serialized_options = b'\340A\003'
  _TRACE.fields_by_name['outputs']._options = None
  _TRACE.fields_by_name['outputs']._serialized_options = b'\340A\003'
  _TRACE.fields_by_name['error']._options = None
  _TRACE.fields_by_name['error']._serialized_options = b'\340A\003'
  _TRACE.fields_by_name['compute_time_in_seconds']._options = None
  _TRACE.fields_by_name['compute_time_in_seconds']._serialized_options = b'\340A\003'
  _GETHUBSTATSRESPONSE.fields_by_name['number_of_public_pipelines']._options = None
  _GETHUBSTATSRESPONSE.fields_by_name['number_of_public_pipelines']._serialized_options = b'\340A\003'
  _GETHUBSTATSRESPONSE.fields_by_name['number_of_featured_pipelines']._options = None
  _GETHUBSTATSRESPONSE.fields_by_name['number_of_featured_pipelines']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['name']._options = None
  _PIPELINERELEASE.fields_by_name['name']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['uid']._options = None
  _PIPELINERELEASE.fields_by_name['uid']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['id']._options = None
  _PIPELINERELEASE.fields_by_name['id']._serialized_options = b'\340A\005'
  _PIPELINERELEASE.fields_by_name['description']._options = None
  _PIPELINERELEASE.fields_by_name['description']._serialized_options = b'\340A\001'
  _PIPELINERELEASE.fields_by_name['recipe']._options = None
  _PIPELINERELEASE.fields_by_name['recipe']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['create_time']._options = None
  _PIPELINERELEASE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['update_time']._options = None
  _PIPELINERELEASE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['delete_time']._options = None
  _PIPELINERELEASE.fields_by_name['delete_time']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['alias']._options = None
  _PIPELINERELEASE.fields_by_name['alias']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['readme']._options = None
  _PIPELINERELEASE.fields_by_name['readme']._serialized_options = b'\340A\001'
  _PIPELINERELEASE.fields_by_name['data_specification']._options = None
  _PIPELINERELEASE.fields_by_name['data_specification']._serialized_options = b'\340A\003'
  _PIPELINERELEASE.fields_by_name['raw_recipe']._options = None
  _PIPELINERELEASE.fields_by_name['raw_recipe']._serialized_options = b'\340A\001'
  _PIPELINERELEASE.fields_by_name['endpoints']._options = None
  _PIPELINERELEASE.fields_by_name['endpoints']._serialized_options = b'\340A\003'
  _LISTPIPELINESREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINESREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTPIPELINESREQUEST.fields_by_name['view']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTPIPELINESREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTPIPELINESREQUEST.fields_by_name['visibility']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTPIPELINESREQUEST.fields_by_name['order_by']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTPIPELINESRESPONSE.fields_by_name['pipelines']._options = None
  _LISTPIPELINESRESPONSE.fields_by_name['pipelines']._serialized_options = b'\340A\003'
  _LISTPIPELINESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTPIPELINESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTPIPELINESRESPONSE.fields_by_name['total_size']._options = None
  _LISTPIPELINESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['view']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['filter']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['visibility']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['order_by']._options = None
  _LISTNAMESPACEPIPELINESREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINESRESPONSE.fields_by_name['pipelines']._options = None
  _LISTNAMESPACEPIPELINESRESPONSE.fields_by_name['pipelines']._serialized_options = b'\340A\003'
  _LISTNAMESPACEPIPELINESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACEPIPELINESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACEPIPELINESRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACEPIPELINESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LOOKUPPIPELINEREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPPIPELINEREQUEST.fields_by_name['permalink']._serialized_options = b'\340A\002'
  _LOOKUPPIPELINEREQUEST.fields_by_name['view']._options = None
  _LOOKUPPIPELINEREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LOOKUPPIPELINERESPONSE.fields_by_name['pipeline']._options = None
  _LOOKUPPIPELINERESPONSE.fields_by_name['pipeline']._serialized_options = b'\340A\003'
  _CREATENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._options = None
  _CREATENAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._serialized_options = b'\340A\003'
  _GETNAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _GETNAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEPIPELINEREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACEPIPELINEREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETNAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._options = None
  _GETNAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._serialized_options = b'\340A\003'
  _UPDATENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _UPDATENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEPIPELINEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACEPIPELINEREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._options = None
  _UPDATENAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._serialized_options = b'\340A\003'
  _DELETENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _DELETENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _VALIDATENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _VALIDATENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _VALIDATENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _VALIDATENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _VALIDATENAMESPACEPIPELINERESPONSE.fields_by_name['success']._options = None
  _VALIDATENAMESPACEPIPELINERESPONSE.fields_by_name['success']._serialized_options = b'\340A\003'
  _VALIDATENAMESPACEPIPELINERESPONSE.fields_by_name['errors']._options = None
  _VALIDATENAMESPACEPIPELINERESPONSE.fields_by_name['errors']._serialized_options = b'\340A\003'
  _RENAMENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _RENAMENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _RENAMENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _RENAMENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _RENAMENAMESPACEPIPELINEREQUEST.fields_by_name['new_pipeline_id']._options = None
  _RENAMENAMESPACEPIPELINEREQUEST.fields_by_name['new_pipeline_id']._serialized_options = b'\340A\002'
  _RENAMENAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._options = None
  _RENAMENAMESPACEPIPELINERESPONSE.fields_by_name['pipeline']._serialized_options = b'\340A\003'
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['description']._options = None
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['description']._serialized_options = b'\340A\001'
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['sharing']._options = None
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['sharing']._serialized_options = b'\340A\001'
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['target_namespace_id']._options = None
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['target_namespace_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['target_pipeline_id']._options = None
  _CLONENAMESPACEPIPELINEREQUEST.fields_by_name['target_pipeline_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._options = None
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._options = None
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._options = None
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['description']._options = None
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['description']._serialized_options = b'\340A\001'
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['sharing']._options = None
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['sharing']._serialized_options = b'\340A\001'
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['target_namespace_id']._options = None
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['target_namespace_id']._serialized_options = b'\340A\002'
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['target_pipeline_id']._options = None
  _CLONENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['target_pipeline_id']._serialized_options = b'\340A\002'
  _SENDNAMESPACEPIPELINEEVENTREQUEST.fields_by_name['namespace_id']._options = None
  _SENDNAMESPACEPIPELINEEVENTREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _SENDNAMESPACEPIPELINEEVENTREQUEST.fields_by_name['pipeline_id']._options = None
  _SENDNAMESPACEPIPELINEEVENTREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _SENDNAMESPACEPIPELINERELEASEEVENTREQUEST.fields_by_name['namespace_id']._options = None
  _SENDNAMESPACEPIPELINERELEASEEVENTREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _SENDNAMESPACEPIPELINERELEASEEVENTREQUEST.fields_by_name['pipeline_id']._options = None
  _SENDNAMESPACEPIPELINERELEASEEVENTREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _SENDNAMESPACEPIPELINERELEASEEVENTREQUEST.fields_by_name['release_id']._options = None
  _SENDNAMESPACEPIPELINERELEASEEVENTREQUEST.fields_by_name['release_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['inputs']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['data']._options = None
  _TRIGGERNAMESPACEPIPELINEREQUEST.fields_by_name['data']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINERESPONSE.fields_by_name['outputs']._options = None
  _TRIGGERNAMESPACEPIPELINERESPONSE.fields_by_name['outputs']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACEPIPELINERESPONSE.fields_by_name['metadata']._options = None
  _TRIGGERNAMESPACEPIPELINERESPONSE.fields_by_name['metadata']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['pipeline_id']._options = None
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['inputs']._serialized_options = b'\340A\001'
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['data']._options = None
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST.fields_by_name['data']._serialized_options = b'\340A\001'
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMRESPONSE.fields_by_name['outputs']._options = None
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMRESPONSE.fields_by_name['outputs']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMRESPONSE.fields_by_name['metadata']._options = None
  _TRIGGERNAMESPACEPIPELINEWITHSTREAMRESPONSE.fields_by_name['metadata']._serialized_options = b'\340A\003'
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['inputs']._serialized_options = b'\340A\001'
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['data']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINEREQUEST.fields_by_name['data']._serialized_options = b'\340A\001'
  _TRIGGERASYNCNAMESPACEPIPELINERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINERESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _CREATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._options = None
  _CREATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACEPIPELINERELEASERESPONSE.fields_by_name['release']._options = None
  _CREATENAMESPACEPIPELINERELEASERESPONSE.fields_by_name['release']._serialized_options = b'\340A\003'
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['pipeline_id']._options = None
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['view']._options = None
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['filter']._options = None
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTNAMESPACEPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTNAMESPACEPIPELINERELEASESRESPONSE.fields_by_name['releases']._options = None
  _LISTNAMESPACEPIPELINERELEASESRESPONSE.fields_by_name['releases']._serialized_options = b'\340A\003'
  _LISTNAMESPACEPIPELINERELEASESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACEPIPELINERELEASESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACEPIPELINERELEASESRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACEPIPELINERELEASESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._options = None
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._options = None
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['release']._options = None
  _GETNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['release']._serialized_options = b'\340A\003'
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._options = None
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._options = None
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEPIPELINERELEASERESPONSE.fields_by_name['release']._options = None
  _UPDATENAMESPACEPIPELINERELEASERESPONSE.fields_by_name['release']._serialized_options = b'\340A\003'
  _DELETENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._options = None
  _DELETENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._options = None
  _DELETENAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._options = None
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._options = None
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['inputs']._serialized_options = b'\340A\001'
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['data']._options = None
  _TRIGGERNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['data']._serialized_options = b'\340A\001'
  _TRIGGERNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['outputs']._options = None
  _TRIGGERNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['outputs']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['metadata']._options = None
  _TRIGGERNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['metadata']._serialized_options = b'\340A\003'
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['release_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['inputs']._serialized_options = b'\340A\001'
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['data']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST.fields_by_name['data']._serialized_options = b'\340A\001'
  _TRIGGERASYNCNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCNAMESPACEPIPELINERELEASERESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _CREATEUSERPIPELINEREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERPIPELINEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['view']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['filter']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['parent']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTUSERPIPELINESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['visibility']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['order_by']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _GETUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _GETUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _GETUSERPIPELINEREQUEST.fields_by_name['view']._options = None
  _GETUSERPIPELINEREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['pipeline']._options = None
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['pipeline']._serialized_options = b'\340A\002'
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _DELETEUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _VALIDATEUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _VALIDATEUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['new_pipeline_id']._options = None
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['new_pipeline_id']._serialized_options = b'\340A\002'
  _TRIGGERUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERUSERPIPELINEWITHSTREAMREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERPIPELINEWITHSTREAMREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERDATA_SECRETENTRY._options = None
  _TRIGGERDATA_SECRETENTRY._serialized_options = b'8\001'
  _TRIGGERDATA.fields_by_name['variable']._options = None
  _TRIGGERDATA.fields_by_name['variable']._serialized_options = b'\340A\001'
  _TRIGGERDATA.fields_by_name['secret']._options = None
  _TRIGGERDATA.fields_by_name['secret']._serialized_options = b'\340A\001'
  _TRIGGERASYNCUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERASYNCUSERPIPELINERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERPIPELINERESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _CREATEUSERPIPELINERELEASEREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERPIPELINERELEASEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['view']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['filter']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['parent']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['view']._options = None
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['release']._options = None
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['release']._serialized_options = b'\340A\002'
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _DELETEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _RESTOREUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RESTOREUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._options = None
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._serialized_options = b'\340A\002'
  _TRIGGERUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERASYNCUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERASYNCUSERPIPELINERELEASERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERPIPELINERELEASERESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _CREATEORGANIZATIONPIPELINEREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONPIPELINEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['visibility']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['order_by']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['pipeline']._options = None
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['pipeline']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _VALIDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _VALIDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['new_pipeline_id']._options = None
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['new_pipeline_id']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERORGANIZATIONPIPELINESTREAMREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONPIPELINESTREAMREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERASYNCORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERASYNCORGANIZATIONPIPELINERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINERESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _CREATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['release']._options = None
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['release']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _RESTOREORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RESTOREORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._options = None
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\340A\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _GETOPERATIONREQUEST.fields_by_name['operation_id']._options = None
  _GETOPERATIONREQUEST.fields_by_name['operation_id']._serialized_options = b'\340A\002'
  _GETOPERATIONRESPONSE.fields_by_name['operation']._options = None
  _GETOPERATIONRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['view']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['view']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['permalink']._serialized_options = b'\222A\030\312>\025\372\002\022pipeline_permalink\340A\002\372A\033\n\031api.instill.tech/Pipeline'
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTPIPELINERUNSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTPIPELINERUNSREQUEST.fields_by_name['pipeline_id']._options = None
  _LISTPIPELINERUNSREQUEST.fields_by_name['pipeline_id']._serialized_options = b'\340A\002'
  _LISTPIPELINERUNSREQUEST.fields_by_name['page']._options = None
  _LISTPIPELINERUNSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINERUNSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINERUNSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSREQUEST.fields_by_name['order_by']._options = None
  _LISTPIPELINERUNSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['page']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['order_by']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTPIPELINERUNSRESPONSE.fields_by_name['pipeline_runs']._options = None
  _LISTPIPELINERUNSRESPONSE.fields_by_name['pipeline_runs']._serialized_options = b'\340A\003'
  _LISTPIPELINERUNSRESPONSE.fields_by_name['total_size']._options = None
  _LISTPIPELINERUNSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTPIPELINERUNSRESPONSE.fields_by_name['page']._options = None
  _LISTPIPELINERUNSRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _LISTPIPELINERUNSRESPONSE.fields_by_name['page_size']._options = None
  _LISTPIPELINERUNSRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['pipeline_runs']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['pipeline_runs']._serialized_options = b'\340A\003'
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['total_size']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['page']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['page_size']._options = None
  _LISTPIPELINERUNSBYCREDITOWNERRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['pipeline_run_id']._options = None
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['pipeline_run_id']._serialized_options = b'\340A\002'
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['page']._options = None
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['page_size']._options = None
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['filter']._options = None
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['order_by']._options = None
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['view']._options = None
  _LISTCOMPONENTRUNSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['component_runs']._options = None
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['component_runs']._serialized_options = b'\340A\003'
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['total_size']._options = None
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['page']._options = None
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['page_size']._options = None
  _LISTCOMPONENTRUNSRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _FILEREFERENCE.fields_by_name['name']._options = None
  _FILEREFERENCE.fields_by_name['name']._serialized_options = b'\340A\002'
  _FILEREFERENCE.fields_by_name['type']._options = None
  _FILEREFERENCE.fields_by_name['type']._serialized_options = b'\340A\002'
  _FILEREFERENCE.fields_by_name['size']._options = None
  _FILEREFERENCE.fields_by_name['size']._serialized_options = b'\340A\002'
  _FILEREFERENCE.fields_by_name['url']._options = None
  _FILEREFERENCE.fields_by_name['url']._serialized_options = b'\340A\002'
  _PIPELINERUN.fields_by_name['pipeline_uid']._options = None
  _PIPELINERUN.fields_by_name['pipeline_uid']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['pipeline_run_uid']._options = None
  _PIPELINERUN.fields_by_name['pipeline_run_uid']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['pipeline_version']._options = None
  _PIPELINERUN.fields_by_name['pipeline_version']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['status']._options = None
  _PIPELINERUN.fields_by_name['status']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['source']._options = None
  _PIPELINERUN.fields_by_name['source']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['total_duration']._options = None
  _PIPELINERUN.fields_by_name['total_duration']._serialized_options = b'\340A\003\340A\001'
  _PIPELINERUN.fields_by_name['runner_id']._options = None
  _PIPELINERUN.fields_by_name['runner_id']._serialized_options = b'\340A\003\340A\001'
  _PIPELINERUN.fields_by_name['inputs']._options = None
  _PIPELINERUN.fields_by_name['inputs']._serialized_options = b'\340A\003\340A\001'
  _PIPELINERUN.fields_by_name['outputs']._options = None
  _PIPELINERUN.fields_by_name['outputs']._serialized_options = b'\340A\003\340A\001'
  _PIPELINERUN.fields_by_name['recipe_snapshot']._options = None
  _PIPELINERUN.fields_by_name['recipe_snapshot']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['start_time']._options = None
  _PIPELINERUN.fields_by_name['start_time']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['complete_time']._options = None
  _PIPELINERUN.fields_by_name['complete_time']._serialized_options = b'\340A\003\340A\001'
  _PIPELINERUN.fields_by_name['error']._options = None
  _PIPELINERUN.fields_by_name['error']._serialized_options = b'\340A\003\340A\001'
  _PIPELINERUN.fields_by_name['credit_amount']._options = None
  _PIPELINERUN.fields_by_name['credit_amount']._serialized_options = b'\340A\003\340A\001'
  _PIPELINERUN.fields_by_name['data_specification']._options = None
  _PIPELINERUN.fields_by_name['data_specification']._serialized_options = b'\340A\003'
  _PIPELINERUN.fields_by_name['pipeline_id']._options = None
  _PIPELINERUN.fields_by_name['pipeline_id']._serialized_options = b'\340A\003\340A\001'
  _COMPONENTRUN.fields_by_name['pipeline_run_uid']._options = None
  _COMPONENTRUN.fields_by_name['pipeline_run_uid']._serialized_options = b'\340A\003'
  _COMPONENTRUN.fields_by_name['component_id']._options = None
  _COMPONENTRUN.fields_by_name['component_id']._serialized_options = b'\340A\003'
  _COMPONENTRUN.fields_by_name['status']._options = None
  _COMPONENTRUN.fields_by_name['status']._serialized_options = b'\340A\003'
  _COMPONENTRUN.fields_by_name['total_duration']._options = None
  _COMPONENTRUN.fields_by_name['total_duration']._serialized_options = b'\340A\003\340A\001'
  _COMPONENTRUN.fields_by_name['start_time']._options = None
  _COMPONENTRUN.fields_by_name['start_time']._serialized_options = b'\340A\003'
  _COMPONENTRUN.fields_by_name['complete_time']._options = None
  _COMPONENTRUN.fields_by_name['complete_time']._serialized_options = b'\340A\003\340A\001'
  _COMPONENTRUN.fields_by_name['error']._options = None
  _COMPONENTRUN.fields_by_name['error']._serialized_options = b'\340A\003\340A\001'
  _COMPONENTRUN.fields_by_name['inputs_reference']._options = None
  _COMPONENTRUN.fields_by_name['inputs_reference']._serialized_options = b'\340A\003'
  _COMPONENTRUN.fields_by_name['inputs']._options = None
  _COMPONENTRUN.fields_by_name['inputs']._serialized_options = b'\340A\003\340A\001'
  _COMPONENTRUN.fields_by_name['outputs_reference']._options = None
  _COMPONENTRUN.fields_by_name['outputs_reference']._serialized_options = b'\340A\003'
  _COMPONENTRUN.fields_by_name['outputs']._options = None
  _COMPONENTRUN.fields_by_name['outputs']._serialized_options = b'\340A\003\340A\001'
  _COMPONENTRUN.fields_by_name['credit_amount']._options = None
  _COMPONENTRUN.fields_by_name['credit_amount']._serialized_options = b'\340A\003\340A\001'
  _globals['_STATE']._serialized_start=30562
  _globals['_STATE']._serialized_end=30647
  _globals['_LIVENESSREQUEST']._serialized_start=488
  _globals['_LIVENESSREQUEST']._serialized_end=637
  _globals['_LIVENESSRESPONSE']._serialized_start=639
  _globals['_LIVENESSRESPONSE']._serialized_end=757
  _globals['_READINESSREQUEST']._serialized_start=760
  _globals['_READINESSREQUEST']._serialized_end=910
  _globals['_READINESSRESPONSE']._serialized_start=912
  _globals['_READINESSRESPONSE']._serialized_end=1031
  _globals['_ENDPOINTS']._serialized_start=1034
  _globals['_ENDPOINTS']._serialized_end=1314
  _globals['_ENDPOINTS_WEBHOOKENDPOINT']._serialized_start=1126
  _globals['_ENDPOINTS_WEBHOOKENDPOINT']._serialized_end=1205
  _globals['_ENDPOINTS_WEBHOOKSENTRY']._serialized_start=1207
  _globals['_ENDPOINTS_WEBHOOKSENTRY']._serialized_end=1314
  _globals['_PIPELINE']._serialized_start=1317
  _globals['_PIPELINE']._serialized_end=3057
  _globals['_PIPELINE_STATS']._serialized_start=2619
  _globals['_PIPELINE_STATS']._serialized_end=2785
  _globals['_PIPELINE_VIEW']._serialized_start=2787
  _globals['_PIPELINE_VIEW']._serialized_end=2863
  _globals['_PIPELINE_VISIBILITY']._serialized_start=2865
  _globals['_PIPELINE_VISIBILITY']._serialized_end=2952
  _globals['_TRIGGERMETADATA']._serialized_start=3060
  _globals['_TRIGGERMETADATA']._serialized_end=3243
  _globals['_TRIGGERMETADATA_TRACESENTRY']._serialized_start=3158
  _globals['_TRIGGERMETADATA_TRACESENTRY']._serialized_end=3243
  _globals['_TRACE']._serialized_start=3246
  _globals['_TRACE']._serialized_end=3637
  _globals['_TRACE_STATUS']._serialized_start=3545
  _globals['_TRACE_STATUS']._serialized_end=3637
  _globals['_GETHUBSTATSREQUEST']._serialized_start=3639
  _globals['_GETHUBSTATSREQUEST']._serialized_end=3659
  _globals['_GETHUBSTATSRESPONSE']._serialized_start=3662
  _globals['_GETHUBSTATSRESPONSE']._serialized_end=3819
  _globals['_PIPELINERELEASE']._serialized_start=3822
  _globals['_PIPELINERELEASE']._serialized_end=4530
  _globals['_LISTPIPELINESREQUEST']._serialized_start=4533
  _globals['_LISTPIPELINESREQUEST']._serialized_end=4995
  _globals['_LISTPIPELINESRESPONSE']._serialized_start=4998
  _globals['_LISTPIPELINESRESPONSE']._serialized_end=5168
  _globals['_LISTNAMESPACEPIPELINESREQUEST']._serialized_start=5171
  _globals['_LISTNAMESPACEPIPELINESREQUEST']._serialized_end=5682
  _globals['_LISTNAMESPACEPIPELINESRESPONSE']._serialized_start=5685
  _globals['_LISTNAMESPACEPIPELINESRESPONSE']._serialized_end=5864
  _globals['_LOOKUPPIPELINEREQUEST']._serialized_start=5867
  _globals['_LOOKUPPIPELINEREQUEST']._serialized_end=6000
  _globals['_LOOKUPPIPELINERESPONSE']._serialized_start=6002
  _globals['_LOOKUPPIPELINERESPONSE']._serialized_end=6090
  _globals['_CREATENAMESPACEPIPELINEREQUEST']._serialized_start=6093
  _globals['_CREATENAMESPACEPIPELINEREQUEST']._serialized_end=6224
  _globals['_CREATENAMESPACEPIPELINERESPONSE']._serialized_start=6226
  _globals['_CREATENAMESPACEPIPELINERESPONSE']._serialized_end=6323
  _globals['_GETNAMESPACEPIPELINEREQUEST']._serialized_start=6326
  _globals['_GETNAMESPACEPIPELINEREQUEST']._serialized_end=6508
  _globals['_GETNAMESPACEPIPELINERESPONSE']._serialized_start=6510
  _globals['_GETNAMESPACEPIPELINERESPONSE']._serialized_end=6604
  _globals['_UPDATENAMESPACEPIPELINEREQUEST']._serialized_start=6607
  _globals['_UPDATENAMESPACEPIPELINEREQUEST']._serialized_end=6842
  _globals['_UPDATENAMESPACEPIPELINERESPONSE']._serialized_start=6844
  _globals['_UPDATENAMESPACEPIPELINERESPONSE']._serialized_end=6941
  _globals['_DELETENAMESPACEPIPELINEREQUEST']._serialized_start=6943
  _globals['_DELETENAMESPACEPIPELINEREQUEST']._serialized_end=7053
  _globals['_DELETENAMESPACEPIPELINERESPONSE']._serialized_start=7055
  _globals['_DELETENAMESPACEPIPELINERESPONSE']._serialized_end=7088
  _globals['_VALIDATENAMESPACEPIPELINEREQUEST']._serialized_start=7090
  _globals['_VALIDATENAMESPACEPIPELINEREQUEST']._serialized_end=7202
  _globals['_VALIDATENAMESPACEPIPELINERESPONSE']._serialized_start=7205
  _globals['_VALIDATENAMESPACEPIPELINERESPONSE']._serialized_end=7344
  _globals['_RENAMENAMESPACEPIPELINEREQUEST']._serialized_start=7347
  _globals['_RENAMENAMESPACEPIPELINEREQUEST']._serialized_end=7502
  _globals['_RENAMENAMESPACEPIPELINERESPONSE']._serialized_start=7504
  _globals['_RENAMENAMESPACEPIPELINERESPONSE']._serialized_end=7601
  _globals['_CLONENAMESPACEPIPELINEREQUEST']._serialized_start=7604
  _globals['_CLONENAMESPACEPIPELINEREQUEST']._serialized_end=7923
  _globals['_CLONENAMESPACEPIPELINERESPONSE']._serialized_start=7925
  _globals['_CLONENAMESPACEPIPELINERESPONSE']._serialized_end=7957
  _globals['_CLONENAMESPACEPIPELINERELEASEREQUEST']._serialized_start=7960
  _globals['_CLONENAMESPACEPIPELINERELEASEREQUEST']._serialized_end=8322
  _globals['_CLONENAMESPACEPIPELINERELEASERESPONSE']._serialized_start=8324
  _globals['_CLONENAMESPACEPIPELINERELEASERESPONSE']._serialized_end=8363
  _globals['_SENDNAMESPACEPIPELINEEVENTREQUEST']._serialized_start=8366
  _globals['_SENDNAMESPACEPIPELINEEVENTREQUEST']._serialized_end=8566
  _globals['_SENDNAMESPACEPIPELINEEVENTRESPONSE']._serialized_start=8568
  _globals['_SENDNAMESPACEPIPELINEEVENTRESPONSE']._serialized_end=8649
  _globals['_SENDNAMESPACEPIPELINERELEASEEVENTREQUEST']._serialized_start=8652
  _globals['_SENDNAMESPACEPIPELINERELEASEEVENTREQUEST']._serialized_end=8895
  _globals['_SENDNAMESPACEPIPELINERELEASEEVENTRESPONSE']._serialized_start=8897
  _globals['_SENDNAMESPACEPIPELINERELEASEEVENTRESPONSE']._serialized_end=8985
  _globals['_TRIGGERNAMESPACEPIPELINEREQUEST']._serialized_start=8988
  _globals['_TRIGGERNAMESPACEPIPELINEREQUEST']._serialized_end=9212
  _globals['_TRIGGERNAMESPACEPIPELINERESPONSE']._serialized_start=9215
  _globals['_TRIGGERNAMESPACEPIPELINERESPONSE']._serialized_end=9376
  _globals['_TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST']._serialized_start=9379
  _globals['_TRIGGERNAMESPACEPIPELINEWITHSTREAMREQUEST']._serialized_end=9613
  _globals['_TRIGGERNAMESPACEPIPELINEWITHSTREAMRESPONSE']._serialized_start=9616
  _globals['_TRIGGERNAMESPACEPIPELINEWITHSTREAMRESPONSE']._serialized_end=9787
  _globals['_TRIGGERASYNCNAMESPACEPIPELINEREQUEST']._serialized_start=9790
  _globals['_TRIGGERASYNCNAMESPACEPIPELINEREQUEST']._serialized_end=10019
  _globals['_TRIGGERASYNCNAMESPACEPIPELINERESPONSE']._serialized_start=10021
  _globals['_TRIGGERASYNCNAMESPACEPIPELINERESPONSE']._serialized_end=10126
  _globals['_CREATENAMESPACEPIPELINERELEASEREQUEST']._serialized_start=10129
  _globals['_CREATENAMESPACEPIPELINERELEASEREQUEST']._serialized_end=10310
  _globals['_CREATENAMESPACEPIPELINERELEASERESPONSE']._serialized_start=10312
  _globals['_CREATENAMESPACEPIPELINERELEASERESPONSE']._serialized_end=10421
  _globals['_LISTNAMESPACEPIPELINERELEASESREQUEST']._serialized_start=10424
  _globals['_LISTNAMESPACEPIPELINERELEASESREQUEST']._serialized_end=10831
  _globals['_LISTNAMESPACEPIPELINERELEASESRESPONSE']._serialized_start=10834
  _globals['_LISTNAMESPACEPIPELINERELEASESRESPONSE']._serialized_end=11025
  _globals['_GETNAMESPACEPIPELINERELEASEREQUEST']._serialized_start=11028
  _globals['_GETNAMESPACEPIPELINERELEASEREQUEST']._serialized_end=11253
  _globals['_GETNAMESPACEPIPELINERELEASERESPONSE']._serialized_start=11255
  _globals['_GETNAMESPACEPIPELINERELEASERESPONSE']._serialized_end=11361
  _globals['_UPDATENAMESPACEPIPELINERELEASEREQUEST']._serialized_start=11364
  _globals['_UPDATENAMESPACEPIPELINERELEASEREQUEST']._serialized_end=11647
  _globals['_UPDATENAMESPACEPIPELINERELEASERESPONSE']._serialized_start=11649
  _globals['_UPDATENAMESPACEPIPELINERELEASERESPONSE']._serialized_end=11758
  _globals['_DELETENAMESPACEPIPELINERELEASEREQUEST']._serialized_start=11761
  _globals['_DELETENAMESPACEPIPELINERELEASEREQUEST']._serialized_end=11914
  _globals['_DELETENAMESPACEPIPELINERELEASERESPONSE']._serialized_start=11916
  _globals['_DELETENAMESPACEPIPELINERELEASERESPONSE']._serialized_end=11956
  _globals['_TRIGGERNAMESPACEPIPELINERELEASEREQUEST']._serialized_start=11959
  _globals['_TRIGGERNAMESPACEPIPELINERELEASEREQUEST']._serialized_end=12226
  _globals['_TRIGGERNAMESPACEPIPELINERELEASERESPONSE']._serialized_start=12229
  _globals['_TRIGGERNAMESPACEPIPELINERELEASERESPONSE']._serialized_end=12397
  _globals['_TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST']._serialized_start=12400
  _globals['_TRIGGERASYNCNAMESPACEPIPELINERELEASEREQUEST']._serialized_end=12672
  _globals['_TRIGGERASYNCNAMESPACEPIPELINERELEASERESPONSE']._serialized_start=12674
  _globals['_TRIGGERASYNCNAMESPACEPIPELINERELEASERESPONSE']._serialized_end=12786
  _globals['_CREATEUSERPIPELINEREQUEST']._serialized_start=12789
  _globals['_CREATEUSERPIPELINEREQUEST']._serialized_end=12952
  _globals['_CREATEUSERPIPELINERESPONSE']._serialized_start=12954
  _globals['_CREATEUSERPIPELINERESPONSE']._serialized_end=13041
  _globals['_LISTUSERPIPELINESREQUEST']._serialized_start=13044
  _globals['_LISTUSERPIPELINESREQUEST']._serialized_end=13587
  _globals['_LISTUSERPIPELINESRESPONSE']._serialized_start=13590
  _globals['_LISTUSERPIPELINESRESPONSE']._serialized_end=13749
  _globals['_GETUSERPIPELINEREQUEST']._serialized_start=13752
  _globals['_GETUSERPIPELINEREQUEST']._serialized_end=13933
  _globals['_GETUSERPIPELINERESPONSE']._serialized_start=13935
  _globals['_GETUSERPIPELINERESPONSE']._serialized_end=14019
  _globals['_UPDATEUSERPIPELINEREQUEST']._serialized_start=14022
  _globals['_UPDATEUSERPIPELINEREQUEST']._serialized_end=14179
  _globals['_UPDATEUSERPIPELINERESPONSE']._serialized_start=14181
  _globals['_UPDATEUSERPIPELINERESPONSE']._serialized_end=14268
  _globals['_DELETEUSERPIPELINEREQUEST']._serialized_start=14270
  _globals['_DELETEUSERPIPELINEREQUEST']._serialized_end=14379
  _globals['_DELETEUSERPIPELINERESPONSE']._serialized_start=14381
  _globals['_DELETEUSERPIPELINERESPONSE']._serialized_end=14409
  _globals['_ERRPIPELINEVALIDATION']._serialized_start=14411
  _globals['_ERRPIPELINEVALIDATION']._serialized_end=14484
  _globals['_VALIDATEUSERPIPELINEREQUEST']._serialized_start=14486
  _globals['_VALIDATEUSERPIPELINEREQUEST']._serialized_end=14597
  _globals['_VALIDATEUSERPIPELINERESPONSE']._serialized_start=14599
  _globals['_VALIDATEUSERPIPELINERESPONSE']._serialized_end=14723
  _globals['_RENAMEUSERPIPELINEREQUEST']._serialized_start=14726
  _globals['_RENAMEUSERPIPELINEREQUEST']._serialized_end=14880
  _globals['_RENAMEUSERPIPELINERESPONSE']._serialized_start=14882
  _globals['_RENAMEUSERPIPELINERESPONSE']._serialized_end=14969
  _globals['_TRIGGERUSERPIPELINEREQUEST']._serialized_start=14972
  _globals['_TRIGGERUSERPIPELINEREQUEST']._serialized_end=15185
  _globals['_TRIGGERUSERPIPELINERESPONSE']._serialized_start=15188
  _globals['_TRIGGERUSERPIPELINERESPONSE']._serialized_end=15334
  _globals['_TRIGGERUSERPIPELINEWITHSTREAMREQUEST']._serialized_start=15337
  _globals['_TRIGGERUSERPIPELINEWITHSTREAMREQUEST']._serialized_end=15560
  _globals['_TRIGGERUSERPIPELINEWITHSTREAMRESPONSE']._serialized_start=15563
  _globals['_TRIGGERUSERPIPELINEWITHSTREAMRESPONSE']._serialized_end=15719
  _globals['_TRIGGERDATA']._serialized_start=15722
  _globals['_TRIGGERDATA']._serialized_end=15927
  _globals['_TRIGGERDATA_SECRETENTRY']._serialized_start=15870
  _globals['_TRIGGERDATA_SECRETENTRY']._serialized_end=15927
  _globals['_TRIGGERASYNCUSERPIPELINEREQUEST']._serialized_start=15930
  _globals['_TRIGGERASYNCUSERPIPELINEREQUEST']._serialized_end=16148
  _globals['_TRIGGERASYNCUSERPIPELINERESPONSE']._serialized_start=16150
  _globals['_TRIGGERASYNCUSERPIPELINERESPONSE']._serialized_end=16250
  _globals['_CREATEUSERPIPELINERELEASEREQUEST']._serialized_start=16253
  _globals['_CREATEUSERPIPELINERELEASEREQUEST']._serialized_end=16435
  _globals['_CREATEUSERPIPELINERELEASERESPONSE']._serialized_start=16437
  _globals['_CREATEUSERPIPELINERELEASERESPONSE']._serialized_end=16536
  _globals['_LISTUSERPIPELINERELEASESREQUEST']._serialized_start=16539
  _globals['_LISTUSERPIPELINERELEASESREQUEST']._serialized_end=16947
  _globals['_LISTUSERPIPELINERELEASESRESPONSE']._serialized_start=16950
  _globals['_LISTUSERPIPELINERELEASESRESPONSE']._serialized_end=17121
  _globals['_GETUSERPIPELINERELEASEREQUEST']._serialized_start=17124
  _globals['_GETUSERPIPELINERELEASEREQUEST']._serialized_end=17327
  _globals['_GETUSERPIPELINERELEASERESPONSE']._serialized_start=17329
  _globals['_GETUSERPIPELINERELEASERESPONSE']._serialized_end=17425
  _globals['_UPDATEUSERPIPELINERELEASEREQUEST']._serialized_start=17428
  _globals['_UPDATEUSERPIPELINERELEASEREQUEST']._serialized_end=17597
  _globals['_UPDATEUSERPIPELINERELEASERESPONSE']._serialized_start=17599
  _globals['_UPDATEUSERPIPELINERELEASERESPONSE']._serialized_end=17698
  _globals['_DELETEUSERPIPELINERELEASEREQUEST']._serialized_start=17701
  _globals['_DELETEUSERPIPELINERELEASEREQUEST']._serialized_end=17832
  _globals['_DELETEUSERPIPELINERELEASERESPONSE']._serialized_start=17834
  _globals['_DELETEUSERPIPELINERELEASERESPONSE']._serialized_end=17869
  _globals['_RESTOREUSERPIPELINERELEASEREQUEST']._serialized_start=17872
  _globals['_RESTOREUSERPIPELINERELEASEREQUEST']._serialized_end=18004
  _globals['_RESTOREUSERPIPELINERELEASERESPONSE']._serialized_start=18006
  _globals['_RESTOREUSERPIPELINERELEASERESPONSE']._serialized_end=18106
  _globals['_RENAMEUSERPIPELINERELEASEREQUEST']._serialized_start=18109
  _globals['_RENAMEUSERPIPELINERELEASEREQUEST']._serialized_end=18300
  _globals['_RENAMEUSERPIPELINERELEASERESPONSE']._serialized_start=18302
  _globals['_RENAMEUSERPIPELINERELEASERESPONSE']._serialized_end=18401
  _globals['_TRIGGERUSERPIPELINERELEASEREQUEST']._serialized_start=18404
  _globals['_TRIGGERUSERPIPELINERELEASEREQUEST']._serialized_end=18639
  _globals['_TRIGGERUSERPIPELINERELEASERESPONSE']._serialized_start=18642
  _globals['_TRIGGERUSERPIPELINERELEASERESPONSE']._serialized_end=18795
  _globals['_TRIGGERASYNCUSERPIPELINERELEASEREQUEST']._serialized_start=18798
  _globals['_TRIGGERASYNCUSERPIPELINERELEASEREQUEST']._serialized_end=19038
  _globals['_TRIGGERASYNCUSERPIPELINERELEASERESPONSE']._serialized_start=19040
  _globals['_TRIGGERASYNCUSERPIPELINERELEASERESPONSE']._serialized_end=19147
  _globals['_CREATEORGANIZATIONPIPELINEREQUEST']._serialized_start=19150
  _globals['_CREATEORGANIZATIONPIPELINEREQUEST']._serialized_end=19329
  _globals['_CREATEORGANIZATIONPIPELINERESPONSE']._serialized_start=19331
  _globals['_CREATEORGANIZATIONPIPELINERESPONSE']._serialized_end=19426
  _globals['_LISTORGANIZATIONPIPELINESREQUEST']._serialized_start=19429
  _globals['_LISTORGANIZATIONPIPELINESREQUEST']._serialized_end=19988
  _globals['_LISTORGANIZATIONPIPELINESRESPONSE']._serialized_start=19991
  _globals['_LISTORGANIZATIONPIPELINESRESPONSE']._serialized_end=20158
  _globals['_GETORGANIZATIONPIPELINEREQUEST']._serialized_start=20161
  _globals['_GETORGANIZATIONPIPELINEREQUEST']._serialized_end=20358
  _globals['_GETORGANIZATIONPIPELINERESPONSE']._serialized_start=20360
  _globals['_GETORGANIZATIONPIPELINERESPONSE']._serialized_end=20452
  _globals['_UPDATEORGANIZATIONPIPELINEREQUEST']._serialized_start=20455
  _globals['_UPDATEORGANIZATIONPIPELINEREQUEST']._serialized_end=20620
  _globals['_UPDATEORGANIZATIONPIPELINERESPONSE']._serialized_start=20622
  _globals['_UPDATEORGANIZATIONPIPELINERESPONSE']._serialized_end=20717
  _globals['_DELETEORGANIZATIONPIPELINEREQUEST']._serialized_start=20719
  _globals['_DELETEORGANIZATIONPIPELINEREQUEST']._serialized_end=20844
  _globals['_DELETEORGANIZATIONPIPELINERESPONSE']._serialized_start=20846
  _globals['_DELETEORGANIZATIONPIPELINERESPONSE']._serialized_end=20882
  _globals['_VALIDATEORGANIZATIONPIPELINEREQUEST']._serialized_start=20884
  _globals['_VALIDATEORGANIZATIONPIPELINEREQUEST']._serialized_end=21011
  _globals['_VALIDATEORGANIZATIONPIPELINERESPONSE']._serialized_start=21014
  _globals['_VALIDATEORGANIZATIONPIPELINERESPONSE']._serialized_end=21146
  _globals['_RENAMEORGANIZATIONPIPELINEREQUEST']._serialized_start=21149
  _globals['_RENAMEORGANIZATIONPIPELINEREQUEST']._serialized_end=21319
  _globals['_RENAMEORGANIZATIONPIPELINERESPONSE']._serialized_start=21321
  _globals['_RENAMEORGANIZATIONPIPELINERESPONSE']._serialized_end=21416
  _globals['_TRIGGERORGANIZATIONPIPELINEREQUEST']._serialized_start=21419
  _globals['_TRIGGERORGANIZATIONPIPELINEREQUEST']._serialized_end=21648
  _globals['_TRIGGERORGANIZATIONPIPELINERESPONSE']._serialized_start=21651
  _globals['_TRIGGERORGANIZATIONPIPELINERESPONSE']._serialized_end=21805
  _globals['_TRIGGERORGANIZATIONPIPELINESTREAMREQUEST']._serialized_start=21808
  _globals['_TRIGGERORGANIZATIONPIPELINESTREAMREQUEST']._serialized_end=22043
  _globals['_TRIGGERORGANIZATIONPIPELINESTREAMRESPONSE']._serialized_start=22046
  _globals['_TRIGGERORGANIZATIONPIPELINESTREAMRESPONSE']._serialized_end=22206
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINEREQUEST']._serialized_start=22209
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINEREQUEST']._serialized_end=22443
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERESPONSE']._serialized_start=22445
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERESPONSE']._serialized_end=22553
  _globals['_CREATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=22556
  _globals['_CREATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=22754
  _globals['_CREATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=22756
  _globals['_CREATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=22863
  _globals['_LISTORGANIZATIONPIPELINERELEASESREQUEST']._serialized_start=22866
  _globals['_LISTORGANIZATIONPIPELINERELEASESREQUEST']._serialized_end=23290
  _globals['_LISTORGANIZATIONPIPELINERELEASESRESPONSE']._serialized_start=23293
  _globals['_LISTORGANIZATIONPIPELINERELEASESRESPONSE']._serialized_end=23472
  _globals['_GETORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=23475
  _globals['_GETORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=23694
  _globals['_GETORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=23696
  _globals['_GETORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=23800
  _globals['_UPDATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=23803
  _globals['_UPDATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=23980
  _globals['_UPDATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=23982
  _globals['_UPDATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=24089
  _globals['_DELETEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=24092
  _globals['_DELETEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=24239
  _globals['_DELETEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=24241
  _globals['_DELETEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=24284
  _globals['_RESTOREORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=24287
  _globals['_RESTOREORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=24435
  _globals['_RESTOREORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=24437
  _globals['_RESTOREORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=24545
  _globals['_RENAMEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=24548
  _globals['_RENAMEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=24755
  _globals['_RENAMEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=24757
  _globals['_RENAMEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=24864
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=24867
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=25118
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=25121
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=25282
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=25285
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=25541
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=25543
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=25658
  _globals['_GETOPERATIONREQUEST']._serialized_start=25660
  _globals['_GETOPERATIONREQUEST']._serialized_end=25721
  _globals['_GETOPERATIONRESPONSE']._serialized_start=25723
  _globals['_GETOPERATIONRESPONSE']._serialized_end=25811
  _globals['_LISTPIPELINESADMINREQUEST']._serialized_start=25814
  _globals['_LISTPIPELINESADMINREQUEST']._serialized_end=26132
  _globals['_LISTPIPELINESADMINRESPONSE']._serialized_start=26135
  _globals['_LISTPIPELINESADMINRESPONSE']._serialized_end=26295
  _globals['_LISTPIPELINERELEASESADMINREQUEST']._serialized_start=26298
  _globals['_LISTPIPELINERELEASESADMINREQUEST']._serialized_end=26623
  _globals['_LISTPIPELINERELEASESADMINRESPONSE']._serialized_start=26626
  _globals['_LISTPIPELINERELEASESADMINRESPONSE']._serialized_end=26798
  _globals['_LOOKUPPIPELINEADMINREQUEST']._serialized_start=26801
  _globals['_LOOKUPPIPELINEADMINREQUEST']._serialized_end=26996
  _globals['_LOOKUPPIPELINEADMINRESPONSE']._serialized_start=26998
  _globals['_LOOKUPPIPELINEADMINRESPONSE']._serialized_end=27086
  _globals['_LISTPIPELINERUNSREQUEST']._serialized_start=27089
  _globals['_LISTPIPELINERUNSREQUEST']._serialized_end=27352
  _globals['_LISTPIPELINERUNSBYCREDITOWNERREQUEST']._serialized_start=27355
  _globals['_LISTPIPELINERUNSBYCREDITOWNERREQUEST']._serialized_end=27674
  _globals['_LISTPIPELINERUNSRESPONSE']._serialized_start=27677
  _globals['_LISTPIPELINERUNSRESPONSE']._serialized_end=27874
  _globals['_LISTPIPELINERUNSBYCREDITOWNERRESPONSE']._serialized_start=27877
  _globals['_LISTPIPELINERUNSBYCREDITOWNERRESPONSE']._serialized_end=28087
  _globals['_LISTCOMPONENTRUNSREQUEST']._serialized_start=28090
  _globals['_LISTCOMPONENTRUNSREQUEST']._serialized_end=28423
  _globals['_LISTCOMPONENTRUNSRESPONSE']._serialized_start=28426
  _globals['_LISTCOMPONENTRUNSRESPONSE']._serialized_end=28627
  _globals['_FILEREFERENCE']._serialized_start=28629
  _globals['_FILEREFERENCE']._serialized_end=28742
  _globals['_PIPELINERUN']._serialized_start=28745
  _globals['_PIPELINERUN']._serialized_end=29766
  _globals['_COMPONENTRUN']._serialized_start=29769
  _globals['_COMPONENTRUN']._serialized_end=30560
# @@protoc_insertion_point(module_scope)
